tlslite.messages.NextProtocol

Package tlslite :: Module messages :: Class NextProtocol |
[hide private]
[frames] | no frames]

# Class NextProtocol

source code

    HandshakeMsg --+
                   |
                  NextProtocol

Instance Methods | [hide private]
__init__(self) | source code
create(self, next_proto) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Overrides: HandshakeMsg.__init__